==> 1.6.92.tar.gz: lib/src/live_data_self.dart <==
part of '../flutterx_live_data.dart';

/// A [LiveData] instance whose [value] reflects itself
/// You can extend this class and create fields which are also LiveData, then you should call [setFields] in the
/// constructor to mark them as dependency of this instance which will be invalidated along with them
abstract class SelfLiveData<T extends SelfLiveData<T>> extends LiveData<T> {
  final Set<LiveData> _sources = {};

  /// Default constructor
  SelfLiveData() {
    super.setData(this as T);
  }

  @override
  @nonVirtual
  bool shouldUpdateValue(T oldValue, T newValue) => false;

  @override
  @nonVirtual
  @Deprecated('Do not set data on SelfLiveData')
  void postData(FutureOr<T> value) => throw UnsupportedError('cannot set this instance');

  @override
  @nonVirtual
  @Deprecated('Do not set data on SelfLiveData')
  void setData(T value) => throw UnsupportedError('cannot set this instance');

  /// Set dependency fields to given [fields] list
  void setFields(Iterable<LiveData> fields) {
    fields = fields.toSet();
    for (final source in _sources.toSet()) if (!fields.contains(source)) removeField(source);
    fields.forEach(addField);
  }

  /// Add field to dependency fields list
  void addField(LiveData field) => _sources.add(field) ? field.observeForever(_invalidate) : null;

  /// Add field from dependency fields list
  void removeField(LiveData field) => _sources.remove(field) ? field.removeObserver(_invalidate) : null;

  void _invalidate(dynamic _) => invalidate();
}

==> 1.7.2.tar.gz: lib/src/live_data_self.dart <==
part of '../flutterx_live_data.dart';

/// A [LiveData] instance whose [value] reflects itself
/// You can extend this class and create fields which are also LiveData, then you should call [setFields] in the
/// constructor to mark them as dependency of this instance which will be invalidated along with them
abstract class SelfLiveData<T extends SelfLiveData<T>> extends LiveData<T> {
  final Set<LiveData> _sources = {};

  /// Default constructor
  SelfLiveData() {
    super.setData(this as T);
  }

  @override
  @nonVirtual
  bool shouldUpdateValue(T oldValue, T newValue) => false;

  @override
  @nonVirtual
  @Deprecated('Do not set data on SelfLiveData')
  void postData(FutureOr<T> value) => throw UnsupportedError('cannot set this instance');

  @override
  @nonVirtual
  @Deprecated('Do not set data on SelfLiveData')
  void setData(T value) => throw UnsupportedError('cannot set this instance');

  /// Set dependency fields to given [fields] list
  void setFields(Iterable<LiveData> fields) {
    fields = Set.of(fields);
    for (final source in [..._sources]) if (!fields.contains(source)) removeField(source);
    fields.forEach(addField);
  }

  /// Add field to dependency fields list
  void addField(LiveData field) => _sources.add(field) ? field.observeForever(_invalidate) : null;

  /// Add field from dependency fields list
  void removeField(LiveData field) => _sources.remove(field) ? field.removeObserver(_invalidate) : null;

  void _invalidate(dynamic _) => invalidate();
}
